@@ -4,7 +4,7 @@ use 5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use overload
   '""'     => sub { shift->to_string },
@@ -482,6 +482,78 @@ sub hostmask {
   return Net::IPAM::IP->new_from_bytes( ~( $mask->bytes ) );
 }
 
+=head2 bitlen
+
+C<< bitlen >> returns the minimum number of bits to represent a range from base to last
+
+  $n = $b->bitlen
+
+obvious for CIDR blocks:
+
+  $b = Net::IPAM::Block->new('10.0.0.0/24')
+  say $b->bitlen;     # 32 - 24 = 8 bit
+
+  $b = Net::IPAM::Block->new('::/0');
+  say $b->bitlen;     # 128 - 0 = 128 bit
+
+  
+not so obvious for ranges:
+
+  $b = Net::IPAM::Block->new('2001:db8::affe-2001:db8::cafe');
+  say $b->bitlen;     # 15 bit (at least)
+
+=cut
+
+sub bitlen {
+	my $self = shift;
+  my $bits = 32;
+  $bits = 128 if $self->version == 6;
+
+  return _bitlen($self->{base}->bytes, $self->{last}->bytes, $bits);
+}
+
+=head2 iter
+
+C<< iter >> returns the next IP in block, starting with base and stopping at last. Returns undef after last.
+
+  $b = Net::IPAM::Block->new('2001:db8::affe-2001:db8::cafe');
+  while ( my $ip = $b->iter ) {
+    say $ip;
+  }
+
+  OUTPUT:
+
+  fe80::affe
+  fe80::afff
+  fe80::b000
+  fe80::b001
+  ...
+  fe80::cafb
+  fe80::cafc
+  fe80::cafd
+  fe80::cafe
+
+=cut
+
+sub iter {
+  my $self = shift;
+
+  # init
+  unless ( defined $self->{iter} ) {
+
+    # initialize state
+    return $self->{iter} = $self->{base};
+  }
+
+  #next
+  if ( $self->{iter}->cmp( $self->{last} ) < 0 ) {
+    return $self->{iter} = $self->{iter}->incr;
+  }
+
+  # over
+  return;
+}
+
 =head2 cmp
 
   $a->cmp($b)
